********************************************************************************
********************************************************************************
****
**** Replication file 1 for:
****   Gerber, Alan S., Gregory A. Huber, Daniel R. Biggers, and David J.
****     Hendry. "Why Don't People Vote in U.S. Primary Elections? Assessing
****     Theoretical Explanations for Reduced Participation." Electoral Studies.
****
****   This file merges an original survey designed by the authors and carried
****   out by YouGov with campaign spending data and election returns from the
****   U.S. Federal Election Commission.
****
********************************************************************************
********************************************************************************

log using Logs/01_ConstructFinalDataset.txt, text replace

clear
set more off

** users should maintain the given directory structure and set the working
**   directory to be the location of this .do file
*cd ...

** read in 2012 primary election returns
insheet using Data/ElectionReturns/2012congprimary.csv, names comma clear

** generate state fips codes
gen statefips = .
replace statefips = 2 if stateabbreviation == "AK"
replace statefips = 1 if stateabbreviation == "AL"
replace statefips = 5 if stateabbreviation == "AR"
replace statefips = 60 if stateabbreviation == "AS"
replace statefips = 4 if stateabbreviation == "AZ"
replace statefips = 6 if stateabbreviation == "CA"
replace statefips = 8 if stateabbreviation == "CO"
replace statefips = 9 if stateabbreviation == "CT"
replace statefips = 11 if stateabbreviation == "DC"
replace statefips = 10 if stateabbreviation == "DE"
replace statefips = 12 if stateabbreviation == "FL"
replace statefips = 13 if stateabbreviation == "GA"
replace statefips = 66 if stateabbreviation == "GU"
replace statefips = 15 if stateabbreviation == "HI"
replace statefips = 19 if stateabbreviation == "IA"
replace statefips = 16 if stateabbreviation == "ID"
replace statefips = 17 if stateabbreviation == "IL"
replace statefips = 18 if stateabbreviation == "IN"
replace statefips = 20 if stateabbreviation == "KS"
replace statefips = 21 if stateabbreviation == "KY"
replace statefips = 22 if stateabbreviation == "LA"
replace statefips = 25 if stateabbreviation == "MA"
replace statefips = 24 if stateabbreviation == "MD"
replace statefips = 23 if stateabbreviation == "ME"
replace statefips = 26 if stateabbreviation == "MI"
replace statefips = 27 if stateabbreviation == "MN"
replace statefips = 29 if stateabbreviation == "MO"
replace statefips = 28 if stateabbreviation == "MS"
replace statefips = 30 if stateabbreviation == "MT"
replace statefips = 37 if stateabbreviation == "NC"
replace statefips = 38 if stateabbreviation == "ND"
replace statefips = 31 if stateabbreviation == "NE"
replace statefips = 33 if stateabbreviation == "NH"
replace statefips = 34 if stateabbreviation == "NJ"
replace statefips = 35 if stateabbreviation == "NM"
replace statefips = 32 if stateabbreviation == "NV"
replace statefips = 36 if stateabbreviation == "NY"
replace statefips = 39 if stateabbreviation == "OH"
replace statefips = 40 if stateabbreviation == "OK"
replace statefips = 41 if stateabbreviation == "OR"
replace statefips = 42 if stateabbreviation == "PA"
replace statefips = 72 if stateabbreviation == "PR"
replace statefips = 44 if stateabbreviation == "RI"
replace statefips = 45 if stateabbreviation == "SC"
replace statefips = 46 if stateabbreviation == "SD"
replace statefips = 47 if stateabbreviation == "TN"
replace statefips = 48 if stateabbreviation == "TX"
replace statefips = 49 if stateabbreviation == "UT"
replace statefips = 51 if stateabbreviation == "VA"
replace statefips = 78 if stateabbreviation == "VI"
replace statefips = 50 if stateabbreviation == "VT"
replace statefips = 53 if stateabbreviation == "WA"
replace statefips = 55 if stateabbreviation == "WI"
replace statefips = 54 if stateabbreviation == "WV"
replace statefips = 56 if stateabbreviation == "WY"

tab d, mis

** drop if blank
drop if v1 == .

** drop if totalvotes is district or party total
drop if totalvotes == "District Votes:"
drop if totalvotes == "Party Votes:"

** change at-large district labels in FEC data to 01 for consistency
replace d = "01" if d == "00"
replace d = "01" if d == "0"

** drop Senate races
drop if d == "S"

** if there was both a special election and an election for the full term in one
**   filing season, use the full term results
tab d, mis
drop if regexm(d, "UNEXPIRED TERM")
tab d, mis
replace d = subinstr(d, " - FULL TERM", "", .)

** create congressional district variable consistent with other datasets
tab d, mis
destring d, gen(cd)
tab cd, mis

** change party labels:
**   - if D or R are combined with another party, consider it to be D or R
tab party
local dptylist "D*" "D/IDP/WF Combined Parties" "D/IND" "D/PRO/WF" "D/W" /*
  */"D/WF" "D/WF Combined Parties" "D/WF/IDP Combined Parties" "N(D)" "W(D)" /*
  */"W(D)/D"
local rptylist "N(R)" "R*" "R/CON" "R/CRV Combined Parties" /*
  */"R/CRV/IDP Combined Parties" "R/CRV/IDP/TRP Combined Parties" /*
  */"R/CRV/LIB Combined Parties" "R/CRV/TRP Combined Parties" /*
  */"R/IDP Combined Parties" "R/TRP" "R/TRP Combined Parties" "W(R)" "W(R)/R" /*
  */"W(R)/W"
local writeincamp "D/W" "W(D)" "W(D)/D" "W(R)" "W(R)/R" "W(R)/W"

gen pty = "D" if party == "D"
forvalues i = 1/11 {
  local ptylab : word `i' of "`dptylist'"
  replace pty = "D" if party == "`ptylab'"
}

replace pty = "R" if party == "R"
forvalues i = 1/14 {
  local ptylab : word `i' of "`rptylist'"
  replace pty = "R" if party == "`ptylab'"
}

** drop nonpartisan Nebraska primaries
drop if statefips == 31 & party == "N(D)"
drop if statefips == 31 & party == "N(R)"

tab party pty

** create flag for a D or R who ran a write-in campaign
gen writein = 0
forvalues i = 1/6 {
  local write : word `i' of "`writeincamp'"
  replace writein = 1 if party == "`write'"
}

** replace % sign in primary variable
replace primary = subinstr(primary, "%", "", .)

** create flag for unopposed primary races and consider them to be 100%
gen unopposed = primaryvotes == "Unopposed"
replace primary = "100.00" if primaryvotes == "Unopposed"

** create flag for candidates nominated by convention (CT and VA) and consider
**   them to be 100%
gen convention = primaryvotes == "*"
replace convention = 1 if primary == "Convention"
replace primary = "100.00" if primaryvotes == "*"
replace primary = "100.00" if primary == "Convention"

** replace blank primary votes with 0
replace primary = "0.00" if primary == ""

** turn primary percentage into numeric proportion
destring primary, gen(primarypct)
gen primaryprop = primarypct / 100

** generate arbitrary candidate numbers
bysort state cd pty: gen candnum = _n

** subset needed variables
keep statefips cd pty primaryprop candnum unopposed convention

** reshape
reshape wide primaryprop unopposed convention, i(statefips cd pty) j(candnum)
foreach var of varlist primaryprop* {
  replace `var' = 0 if `var' == .
}

** fix unopposed indicator
egen unopposed = rowtotal(unopposed*)
tab unopposed
cl if unopposed1 == 1
cl if unopposed2 == 1
cl if unopposed3 == 1
cl if unopposed4 == 1
cl if unopposed5 == 1
cl if unopposed6 == 1
cl if unopposed7 == 1
cl if unopposed8 == 1
cl if unopposed9 == 1
cl if unopposed10 == 1
cl if unopposed11 == 1
cl if unopposed12 == 1
drop unopposed1 unopposed2 unopposed3 unopposed4 unopposed5 unopposed6 /*
  */unopposed7 unopposed8 unopposed9 unopposed10 unopposed11 unopposed12

** fix convention indicator
egen convention = rowtotal(convention*)
tab convention
cl if convention1 == 1
cl if convention2 == 1
cl if convention3 == 1
cl if convention4 == 1
cl if convention5 == 1
cl if convention6 == 1
cl if convention7 == 1
cl if convention8 == 1
cl if convention9 == 1
cl if convention10 == 1
cl if convention11 == 1
cl if convention12 == 1
drop convention1 convention2 convention3 convention4 convention5 convention6 /*
  */convention7 convention8 convention9 convention10 convention11 convention12

** generate fractionalization index
gen fracindex = 1 - (primaryprop1^2 + primaryprop2^2 + primaryprop3^2 + /*
  */primaryprop4^2 + primaryprop5^2 + primaryprop6^2 + primaryprop7^2 + /*
  */primaryprop8^2 + primaryprop9^2 + primaryprop10^2 + primaryprop11^2 + /*
  */primaryprop12^2)

** reshape
reshape wide primaryprop* unopposed convention fracindex, i(statefips cd) /*
  */j(pty) string

** rename variables
foreach var of varlist primaryprop* unopposed* convention* fracindex* {
  rename `var' `var'12
}

** label fractionalization index
label var fracindexD12 "Fractionalization Index 2012, Democratic Party (0 - 1)"
label var fracindexR12 "Fractionalization Index 2012, Republican Party (0 - 1)"

** save final dataset
save Data/ElectionReturns/FracIndex12.dta, replace

clear

** read in 2012 primary election returns
insheet using Data/ElectionReturns/2014congprimary.csv, names comma clear

* generate state fips codes
gen statefips = .
replace statefips = 2 if stateabbreviation == "AK"
replace statefips = 1 if stateabbreviation == "AL"
replace statefips = 5 if stateabbreviation == "AR"
replace statefips = 60 if stateabbreviation == "AS"
replace statefips = 4 if stateabbreviation == "AZ"
replace statefips = 6 if stateabbreviation == "CA"
replace statefips = 8 if stateabbreviation == "CO"
replace statefips = 9 if stateabbreviation == "CT"
replace statefips = 11 if stateabbreviation == "DC"
replace statefips = 10 if stateabbreviation == "DE"
replace statefips = 12 if stateabbreviation == "FL"
replace statefips = 13 if stateabbreviation == "GA"
replace statefips = 66 if stateabbreviation == "GU"
replace statefips = 15 if stateabbreviation == "HI"
replace statefips = 19 if stateabbreviation == "IA"
replace statefips = 16 if stateabbreviation == "ID"
replace statefips = 17 if stateabbreviation == "IL"
replace statefips = 18 if stateabbreviation == "IN"
replace statefips = 20 if stateabbreviation == "KS"
replace statefips = 21 if stateabbreviation == "KY"
replace statefips = 22 if stateabbreviation == "LA"
replace statefips = 25 if stateabbreviation == "MA"
replace statefips = 24 if stateabbreviation == "MD"
replace statefips = 23 if stateabbreviation == "ME"
replace statefips = 26 if stateabbreviation == "MI"
replace statefips = 27 if stateabbreviation == "MN"
replace statefips = 29 if stateabbreviation == "MO"
replace statefips = 28 if stateabbreviation == "MS"
replace statefips = 30 if stateabbreviation == "MT"
replace statefips = 37 if stateabbreviation == "NC"
replace statefips = 38 if stateabbreviation == "ND"
replace statefips = 31 if stateabbreviation == "NE"
replace statefips = 33 if stateabbreviation == "NH"
replace statefips = 34 if stateabbreviation == "NJ"
replace statefips = 35 if stateabbreviation == "NM"
replace statefips = 32 if stateabbreviation == "NV"
replace statefips = 36 if stateabbreviation == "NY"
replace statefips = 39 if stateabbreviation == "OH"
replace statefips = 40 if stateabbreviation == "OK"
replace statefips = 41 if stateabbreviation == "OR"
replace statefips = 42 if stateabbreviation == "PA"
replace statefips = 72 if stateabbreviation == "PR"
replace statefips = 44 if stateabbreviation == "RI"
replace statefips = 45 if stateabbreviation == "SC"
replace statefips = 46 if stateabbreviation == "SD"
replace statefips = 47 if stateabbreviation == "TN"
replace statefips = 48 if stateabbreviation == "TX"
replace statefips = 49 if stateabbreviation == "UT"
replace statefips = 51 if stateabbreviation == "VA"
replace statefips = 78 if stateabbreviation == "VI"
replace statefips = 50 if stateabbreviation == "VT"
replace statefips = 53 if stateabbreviation == "WA"
replace statefips = 55 if stateabbreviation == "WI"
replace statefips = 54 if stateabbreviation == "WV"
replace statefips = 56 if stateabbreviation == "WY"

tab d, mis

** drop if blank
drop if v1 == .

** drop if totalvotes is district or party total
drop if totalvotes == "District Votes:"
drop if totalvotes == "Party Votes:"

** change at-large district labels in FEC data to 01 for consistency
replace d = "01" if d == "00" 
replace d = "01" if d == "0"

** drop Senate races
drop if d == "S"

** if there was both a special election and an election for the full term in one
**   filing season, use the full term results
tab d, mis
drop if regexm(d, "UNEXPIRED TERM")
tab d, mis
replace d = subinstr(d, " - FULL TERM", "", .)

** create congressional district variable consistent with other datasets
destring d, gen(cd)
tab cd, mis

** change party labels:
**   - if D or R are combined with another party, consider it to be D or R
tab party
local dptylist "D/PRO/WF*" "D/W" "D/WF*" "N(D)" "W(D)"
local rptylist "N(R)" "R/CON*" "R/CON*/IP*" "R/TRP" "R/W" "W(R)" "W(R)/W"
local writeincamp "D/W" "R/W" "W(D)" "W(R)" "W(R)/W"

gen pty = "D" if party == "D"
forvalues i = 1/5 {
  local ptylab : word `i' of "`dptylist'"
  replace pty = "D" if party == "`ptylab'"
}

replace pty = "R" if party == "R"
forvalues i = 1/7 {
  local ptylab : word `i' of "`rptylist'"
  replace pty = "R" if party == "`ptylab'"
}

** drop nonpartisan Nebraska primaries
drop if statefips == 31 & party == "N(D)"
drop if statefips == 31 & party == "N(R)"

tab party pty

** create flag for a D or R who ran a write-in campaign
gen writein = 0
forvalues i = 1/6 {
  local write : word `i' of "`writeincamp'"
  replace writein = 1 if party == "`write'"
}

** replace % sign in primary variable
replace primary = subinstr(primary, "%", "", .)

** create flag for unopposed primary races and consider them to be 100%
gen unopposed = primaryvotes == "Unopposed"
replace primary = "100.00" if primaryvotes == "Unopposed"

** create flag for candidates nominated by convention (CT and VA) and consider 
**   them to be 100%
gen convention = primaryvotes == "*"
replace primary = "100.00" if primaryvotes == "*"

** replace blank primary votes with 0
replace primary = "0.00" if primary == ""

** turn primary percentage into numeric proportion
destring primary, gen(primarypct)
gen primaryprop = primarypct / 100

** generate arbitrary candidate numbers
bysort state cd pty: gen candnum = _n

** subset needed variables
keep statefips cd pty primaryprop candnum unopposed convention

** reshape
reshape wide primaryprop unopposed convention, i(statefips cd pty) j(candnum)
foreach var of varlist primaryprop* {
  replace `var' = 0 if `var' == .
}

** fix unopposed indicator
egen unopposed = rowtotal(unopposed*)
tab unopposed
cl if unopposed1 == 1
cl if unopposed2 == 1
cl if unopposed3 == 1
cl if unopposed4 == 1
cl if unopposed5 == 1
cl if unopposed6 == 1
cl if unopposed7 == 1
cl if unopposed8 == 1
cl if unopposed9 == 1
cl if unopposed10 == 1
cl if unopposed11 == 1
cl if unopposed12 == 1
drop unopposed1 unopposed2 unopposed3 unopposed4 unopposed5 unopposed6 /*
  */unopposed7 unopposed8 unopposed9 unopposed10 unopposed11 unopposed12

** fix convention indicator
egen convention = rowtotal(convention*)
tab convention
cl if convention1 == 1
cl if convention2 == 1
cl if convention3 == 1
cl if convention4 == 1
cl if convention5 == 1
cl if convention6 == 1
cl if convention7 == 1
cl if convention8 == 1
cl if convention9 == 1
cl if convention10 == 1
cl if convention11 == 1
cl if convention12 == 1
drop convention1 convention2 convention3 convention4 convention5 convention6 /*
  */convention7 convention8 convention9 convention10 convention11 convention12

** generate fractionalization index
gen fracindex = 1 - (primaryprop1^2 + primaryprop2^2 + primaryprop3^2 + /*
  */primaryprop4^2 + primaryprop5^2 + primaryprop6^2 + primaryprop7^2 + /*
  */primaryprop8^2 + primaryprop9^2 + primaryprop10^2 + primaryprop11^2 + /*
  */primaryprop12^2)

** reshape
reshape wide primaryprop* unopposed convention fracindex, i(statefips cd) /*
  */j(pty) string

** rename variables
foreach var of varlist primaryprop* unopposed* convention* fracindex* {
  rename `var' `var'14
}

** label fractionalization index
label var fracindexD14 "Fractionalization Index 2014, Democratic Party (0 - 1)"
label var fracindexR14 "Fractionalization Index 2014, Republican Party (0 - 1)"

** save final dataset
save Data/ElectionReturns/FracIndex14.dta, replace

clear

** read in survey data
use Data/Survey/YALE0052_OUTPUT.dta, clear

** merge 2012 fractionalization data
merge m:1 statefips cd using Data/ElectionReturns/FracIndex12.dta, /*
  */gen(frac12merge)
** merge 2014 fractionalization data
merge m:1 statefips cd using Data/ElectionReturns/FracIndex14.dta, /*
  */gen(frac14merge)

** change fractionalization index respondents with missing district info to 0
foreach var of varlist fracindexD12 fracindexR12 fracindexD14 fracindexR14 {
  replace `var' = 0 if miss_cdinfo == 1
}

** merge 2012 campaign spending
merge m:1 statefips cd using /*
  */Data/CampaignSpending/StateDistrictSpending2012.dta, gen(spend_merge2012)
** merge 2014 campaign spending
merge m:1 statefips cd using /*
  */Data/CampaignSpending/StateDistrictSpending2014.dta, gen(spend_merge2014)

** change spending for respondents with missing district info to 0
foreach var of varlist Dspend_12 Dspend_14 Rspend_12 Rspend_14 {
  replace `var' = 0 if miss_cdinfo == 1
}

** save dataset
save Data/PrimarySurveyWithContextVariables.dta, replace

clear

log close
